DeviceAim

Enum DeviceAim 

pub enum DeviceAim {
    Input,
    Output,
}
Used to identify devices as input or output. In this library all devices are either input or output. If a physical device supports both it is exposed as two devices with the same id, but with different aims returned by Device::aim().

Variants



Input

Capture / recording



Output

Playback